summaryrefslogtreecommitdiff
path: root/capture_sync.h
diff options
context:
space:
mode:
Diffstat (limited to 'capture_sync.h')
-rw-r--r--capture_sync.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/capture_sync.h b/capture_sync.h
index 2c4bb639af..2732690573 100644
--- a/capture_sync.h
+++ b/capture_sync.h
@@ -99,10 +99,10 @@ extern gboolean
capture_input_new_file(capture_session *cap_session, gchar *new_file);
/**
* Capture child told us we have new packets to read.
*/
extern void
-capture_input_new_packets(capture_session *cap_session, int to_read);
+capture_input_new_records(capture_session *cap_session, int to_read);
/**
* Capture child told us how many dropped packets it counted.
@@ -99,10 +99,10 @@ extern gboolean
capture_input_new_file(capture_session *cap_session, gchar *new_file);
/**
- * Capture child told us we have new packets to read.
+ * Capture child told us we have new records to read.
*/
extern void